==> 1.1.0.tar.gz: lxqt-config-1.1.0/lxqt-config-monitor/translations/lxqt-config-monitor_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Snabbinställningar</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Utökad vy</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Enhetlig vy</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶ Bara först</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Endast andra</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="97"/>
        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
        <translation>Standardskärmsinställningarna har tillämpats. Om du vill ändra inställningar för bildskärmar, använd lxqt-config-monitor.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Bildskärmsinställningar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Sparade inställningar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Välj</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="62"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="65"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="68"/>
        <source>Inverted</source>
        <translation>Omvänd</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="71"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>True</source>
        <translation>Sant</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>False</source>
        <translation>Falskt</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Håll bildskärmarna anslutna</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Bildskärmsinställningar</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="105"/>
        <source>Fast Menu</source>
        <translation>Snabbmeny</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="109"/>
        <source>Set position</source>
        <translation>Ange position</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="228"/>
        <source>Advanced settings</source>
        <translation>Avancerade inställningar</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Konfiguration</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Upplösning:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Aktivera den här skärmen</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Det här är min primära skärm</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Den här skärmen utökar en annan skärm</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Uppdateringsfrekvens:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Rotation:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Skärminformation</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="128"/>
        <source>Name: %1
</source>
        <translation>Namn: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Vendor: %1
</source>
        <translation>Leverantör: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Serial: %1
</source>
        <translation>Serienummer: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Skärmstorlek: %1 cm x%2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Serial number: %1
</source>
        <translation>Serienummer: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA-enhetens ID: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="153"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Inverted</source>
        <translation>Omvänd</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="244"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Hantera sparade inställningar</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Inställningarna ändras</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Är de aktuella inställningarna OK för dig?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>%n sekund återstår</numerusform>
            <numerusform>%n sekunder återstår</numerusform>
        </translation>
    </message>
</context>
</TS>

==> 2.1.0.tar.gz: lxqt-config-2.1.0/lxqt-config-monitor/translations/lxqt-config-monitor_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Snabbinställningar</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Utökad vy</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Enhetlig vy</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶ Bara först</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Endast andra</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="97"/>
        <source>Default monitor settings applied.</source>
        <translation>Standard skärminställningar tillämpade.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Adjust your screens with LXQt Monitor Settings.</source>
        <translation>Justera dina skärmar med LXQt skärminställningar.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="107"/>
        <source>lxqt-config-monitor: Settings applied.</source>
        <translation>lxqt-config-monitor: Inställningar tillämpade.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="109"/>
        <source>lxqt-config-monitor: Settings not applied.
If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
        <translation>lxqt-config-monitor: Inställningar tillämpas inte.
Om det här är en Wayland-kompositör, kan du prova kanshi för att konfigurera din(a) bildskärm(ar).</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Bildskärmsinställningar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Sparade inställningar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="66"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="69"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="72"/>
        <source>Inverted</source>
        <translation>Omvänd</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>True</source>
        <translation>Sant</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>False</source>
        <translation>Falskt</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="172"/>
        <source>Settings Activation Failed</source>
        <translation>Aktivering av inställningar misslyckades</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="173"/>
        <source>Selected settings cannot be applied with currently active monitors.

Please choose from the highlighted configurations.</source>
        <translation>Valda inställningar kan inte tillämpas med för närvarande aktiva bildskärmar.

Vänligen välj från de markerade konfigurationerna.</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Håll bildskärmarna anslutna</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Bildskärmsinställningar</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="62"/>
        <source>Platform Unsupported</source>
        <translation>Plattform stöds inte</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="63"/>
        <source>LXQt monitor settings are currently unsupported under this wayland compositor.

You can configure your monitor(s) with kanshi.</source>
        <translation>LXQt-skärminställningar stöds för närvarande inte under denna wayland-kompositör.

Du kan konfigurera dina bildskärm(ar) med kanshi.</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="118"/>
        <source>Fast Menu</source>
        <translation>Snabbmeny</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="122"/>
        <source>Set position</source>
        <translation>Ange position</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="241"/>
        <source>Advanced settings</source>
        <translation>Avancerade inställningar</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Konfiguration</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="64"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="80"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="36"/>
        <source>Resolution:</source>
        <translation>Upplösning:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="27"/>
        <source>Enable this display</source>
        <translation>Aktivera den här skärmen</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="49"/>
        <source>This is my primary display</source>
        <translation>Det här är min primära skärm</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="54"/>
        <source>This screen extends another display</source>
        <translation>Den här skärmen utökar en annan skärm</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="143"/>
        <source>Refresh rate:</source>
        <translation>Uppdateringsfrekvens:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="133"/>
        <source>Rotation:</source>
        <translation>Vridning:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Skärminformation</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Namn: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Leverantör: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Serienummer: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Skärmstorlek: %1 cm x%2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Serienummer: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA-enhetens ID: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Inverted</source>
        <translation>Omvänd</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="247"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Hantera sparade inställningar</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Inställningarna ändras</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Är de aktuella inställningarna OK för dig?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>%n sekund återstår</numerusform>
            <numerusform>%n sekunder återstår</numerusform>
        </translation>
    </message>
</context>
</TS>
